# Generated by Django 5.0.4 on 2024-04-24 13:21

import r_shepard.api.models
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("api", "0014_project_max_containers"),
    ]

    operations = [
        migrations.AddField(
            model_name="project",
            name="auto_commit_enabled",
            field=models.BooleanField(
                default=False,
                help_text="Whether automatic commits are enabled for the workspace_path.",
            ),
        ),
        migrations.AddField(
            model_name="project",
            name="git_repo_url",
            field=models.URLField(
                blank=True,
                help_text="URL of the Git repository.",
                max_length=255,
                null=True,
                validators=[r_shepard.api.models.validate_git_url],
            ),
        ),
    ]
