# Generated by Django 5.0.4 on 2024-04-20 16:40

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Project',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(help_text='The name of the project.', max_length=255, unique=True)),
                ('data_path', models.CharField(help_text='Filesystem path where project data is stored.', max_length=1024)),
                ('workspace_path', models.CharField(help_text='Filesystem path where R scripts are stored.', max_length=1024)),
                ('password', models.CharField(help_text='Password for the RStudio Rocker container.', max_length=255)),
                ('ram', models.PositiveIntegerField(help_text='Amount of RAM in MB allocated for the project.')),
                ('cpus', models.PositiveIntegerField(help_text='Number of CPUs allocated to the project.')),
            ],
        ),
    ]
