# Generated by Django 5.0.4 on 2024-04-24 13:32

import datetime
import r_shepard.api.models
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("api", "0015_project_auto_commit_enabled_project_git_repo_url"),
    ]

    operations = [
        migrations.AddField(
            model_name="project",
            name="commit_interval",
            field=models.PositiveIntegerField(
                default=60, help_text="Commit interval in seconds."
            ),
        ),
        migrations.AddField(
            model_name="project",
            name="last_commit_time",
            field=models.DateTimeField(
                auto_now_add=True,
                default=datetime.datetime(
                    2024, 4, 24, 13, 32, 6, 347026, tzinfo=datetime.timezone.utc
                ),
                help_text="Last time the project was committed to the Git repository.",
            ),
            preserve_default=False,
        ),
        migrations.AlterField(
            model_name="project",
            name="git_repo_url",
            field=models.CharField(
                blank=True,
                help_text="URL of the Git repository.",
                max_length=255,
                null=True,
                validators=[r_shepard.api.models.validate_git_url],
            ),
        ),
    ]
