# Generated by Django 5.0.4 on 2024-04-20 17:08

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('api', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='project',
            name='is_active',
            field=models.BooleanField(default=False, help_text="Indicates whether the project's container is running"),
        ),
    ]
