# Generated by Django 5.0.4 on 2024-04-23 09:28

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("api", "0011_alter_container_tailscale_serve_url"),
    ]

    operations = [
        migrations.AddField(
            model_name="project",
            name="slug",
            field=models.SlugField(
                default="test",
                help_text="A URL-safe slug for the project.",
                max_length=255,
                unique=True,
            ),
            preserve_default=False,
        ),
    ]
