# Generated by Django 5.0.4 on 2024-04-20 17:49

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('api', '0003_project_url'),
    ]

    operations = [
        migrations.AddField(
            model_name='project',
            name='rstudio_version',
            field=models.CharField(default='latest', help_text='The version of the RStudio Rocker container.', max_length=255),
        ),
    ]
