# Generated by Django 5.0.4 on 2024-04-23 11:30

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("api", "0012_project_slug"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="project",
            name="password",
        ),
        migrations.AddField(
            model_name="container",
            name="password",
            field=models.CharField(
                default="test",
                help_text="Password for the RStudio Rocker container.",
                max_length=255,
            ),
            preserve_default=False,
        ),
    ]
