{% extends 'admin/base.html' %}
{% block extrastyle %}
  {{ block.super }}
  <style>
  html[data-theme="light"], :root {
    --primary: #2060df;
    --secondary: #2966e0;
    --link-fg: #1c54c4;
    --link-selected-fg: #194cb3;
    --breadcrumbs-bg: #0F2E6B;
  }

  #site-name a:link, #site-name a:visited {
    color: #fff;
  }

  </style>
{% endblock %}
